package cn.iocoder.yudao.module.portal.controller.admin.jobpost;

import org.springframework.web.bind.annotation.*;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.tags.Tag;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Operation;

import javax.validation.constraints.*;
import javax.validation.*;
import javax.servlet.http.*;
import java.util.*;
import java.io.IOException;

import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;
import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

import cn.iocoder.yudao.framework.excel.core.util.ExcelUtils;

import cn.iocoder.yudao.framework.apilog.core.annotation.ApiAccessLog;
import static cn.iocoder.yudao.framework.apilog.core.enums.OperateTypeEnum.*;

import cn.iocoder.yudao.module.portal.controller.admin.jobpost.vo.*;
import cn.iocoder.yudao.module.portal.dal.dataobject.jobpost.JobPostDO;
import cn.iocoder.yudao.module.portal.service.jobpost.JobPostService;

@Tag(name = "管理后台 - 职位")
@RestController
@RequestMapping("/portal/job-post")
@Validated
public class JobPostController {

    @Resource
    private JobPostService jobPostService;

    @PostMapping("/create")
    @Operation(summary = "创建职位")
    @PreAuthorize("@ss.hasPermission('portal:job-post:create')")
    public CommonResult<Long> createJobPost(@Valid @RequestBody JobPostSaveReqVO createReqVO) {
        return success(jobPostService.createJobPost(createReqVO));
    }

    @PutMapping("/update")
    @Operation(summary = "更新职位")
    @PreAuthorize("@ss.hasPermission('portal:job-post:update')")
    public CommonResult<Boolean> updateJobPost(@Valid @RequestBody JobPostSaveReqVO updateReqVO) {
        jobPostService.updateJobPost(updateReqVO);
        return success(true);
    }

    @DeleteMapping("/delete")
    @Operation(summary = "删除职位")
    @Parameter(name = "id", description = "编号", required = true)
    @PreAuthorize("@ss.hasPermission('portal:job-post:delete')")
    public CommonResult<Boolean> deleteJobPost(@RequestParam("id") Long id) {
        jobPostService.deleteJobPost(id);
        return success(true);
    }

    @GetMapping("/get")
    @Operation(summary = "获得职位")
    @Parameter(name = "id", description = "编号", required = true, example = "1024")
    @PreAuthorize("@ss.hasPermission('portal:job-post:query')")
    public CommonResult<JobPostRespVO> getJobPost(@RequestParam("id") Long id) {
        JobPostDO jobPost = jobPostService.getJobPost(id);
        return success(BeanUtils.toBean(jobPost, JobPostRespVO.class));
    }

    @GetMapping("/page")
    @Operation(summary = "获得职位分页")
    @PreAuthorize("@ss.hasPermission('portal:job-post:query')")
    public CommonResult<PageResult<JobPostRespVO>> getJobPostPage(@Valid JobPostPageReqVO pageReqVO) {
        PageResult<JobPostDO> pageResult = jobPostService.getJobPostPage(pageReqVO);
        return success(BeanUtils.toBean(pageResult, JobPostRespVO.class));
    }

    @GetMapping("/export-excel")
    @Operation(summary = "导出职位 Excel")
    @PreAuthorize("@ss.hasPermission('portal:job-post:export')")
    @ApiAccessLog(operateType = EXPORT)
    public void exportJobPostExcel(@Valid JobPostPageReqVO pageReqVO,
              HttpServletResponse response) throws IOException {
        pageReqVO.setPageSize(PageParam.PAGE_SIZE_NONE);
        List<JobPostDO> list = jobPostService.getJobPostPage(pageReqVO).getList();
        // 导出 Excel
        ExcelUtils.write(response, "职位.xls", "数据", JobPostRespVO.class,
                        BeanUtils.toBean(list, JobPostRespVO.class));
    }

}