package cn.iocoder.yudao.module.portal.service.newstype;

import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import cn.iocoder.yudao.module.portal.controller.admin.newstype.vo.*;
import cn.iocoder.yudao.module.portal.dal.dataobject.newstype.NewsTypeDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.common.pojo.PageParam;
import cn.iocoder.yudao.framework.common.util.object.BeanUtils;

import cn.iocoder.yudao.module.portal.dal.mysql.newstype.NewsTypeMapper;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.portal.enums.ErrorCodeConstants.*;

/**
 * 新闻类型 Service 实现类
 *
 * @author 篮智科技
 */
@Service
@Validated
public class NewsTypeServiceImpl implements NewsTypeService {

    @Resource
    private NewsTypeMapper newsTypeMapper;

    @Override
    public Long createNewsType(NewsTypeSaveReqVO createReqVO) {
        // 插入
        NewsTypeDO newsType = BeanUtils.toBean(createReqVO, NewsTypeDO.class);
        newsTypeMapper.insert(newsType);
        // 返回
        return newsType.getId();
    }

    @Override
    public void updateNewsType(NewsTypeSaveReqVO updateReqVO) {
        // 校验存在
        validateNewsTypeExists(updateReqVO.getId());
        // 更新
        NewsTypeDO updateObj = BeanUtils.toBean(updateReqVO, NewsTypeDO.class);
        newsTypeMapper.updateById(updateObj);
    }

    @Override
    public void deleteNewsType(Long id) {
        // 校验存在
        validateNewsTypeExists(id);
        // 删除
        newsTypeMapper.deleteById(id);
    }

    private void validateNewsTypeExists(Long id) {
        if (newsTypeMapper.selectById(id) == null) {
            throw exception(NEWS_TYPE_NOT_EXISTS);
        }
    }

    @Override
    public NewsTypeDO getNewsType(Long id) {
        return newsTypeMapper.selectById(id);
    }

    @Override
    public PageResult<NewsTypeDO> getNewsTypePage(NewsTypePageReqVO pageReqVO) {
        return newsTypeMapper.selectPage(pageReqVO);
    }

}